@@ -4,7 +4,7 @@ from django import forms
 from django.utils.copycompat import deepcopy
 from django.db.models import Q
 
-from datafilters.filterspec import FilterSpec
+from datafilters.filterspec import FilterSpec, RuntimeAwareFilterSpecMixin
 from datafilters.declarative import declarative_fields
 
 
@@ -26,15 +26,14 @@ class FilterForm(forms.Form):
         else:
             self.filter_specs = deepcopy(self.filter_specs_base)
 
-        view_kwargs = kwargs.pop('view_kwargs', {})
+        self.runtime_context = kwargs.pop('runtime_context', {})
+
         super(FilterForm, self).__init__(data=data, **kwargs)
         # Generate form fields
         for name, spec in self.filter_specs.iteritems():
             field_cls, local_field_kwargs = spec.filter_field
             field_kwargs = self.default_fields_args.copy()
             field_kwargs.update(local_field_kwargs)
-            if field_kwargs.has_key('view_kwargs'):
-                field_kwargs['view_kwargs'] = view_kwargs
             self.fields[name] = field_cls(**field_kwargs)
 
         self.spec_count = len(self.filter_specs)
@@ -43,7 +42,11 @@ class FilterForm(forms.Form):
         data = {}
         complex_conditions = []
         for name, spec in self.filter_specs.iteritems():
-            lookup_or_condition = spec.to_lookup(self.cleaned_data.get(name))
+            raw_value = self.cleaned_data.get(name)
+            if isinstance(spec, RuntimeAwareFilterSpecMixin):
+                spec.to_lookup(raw_value, runtime_context=self.runtime_context)
+            else:
+                lookup_or_condition = spec.to_lookup(raw_value)
             if isinstance(lookup_or_condition, Q):
                 complex_conditions.append(lookup_or_condition)
             else:
